@@ -54,15 +54,21 @@ class HikConnect:
             "password": hashlib.md5(password.encode("utf-8")).hexdigest(),
             # "imageCode": "",  # required when CAPTCHA is presented - plaintext captcha input
         }
-        async with self.client.post(f"{self.BASE_URL}/v3/users/login/v2", data=data) as res:
+        async with self.client.post(
+            f"{self.BASE_URL}/v3/users/login/v2", data=data
+        ) as res:
             res_json = await res.json()
         log.debug("Got login response '%s'", res_json)
 
         if res_json["meta"]["code"] in (1013, 1014):
-            raise LoginError("Login failed, probably wrong username/password combination.")
+            raise LoginError(
+                "Login failed, probably wrong username/password combination."
+            )
 
         if res_json["meta"]["code"] == 1015:
-            raise LoginError("CAPTCHA hit, please login using Hik-Connect app and then retry.")
+            raise LoginError(
+                "CAPTCHA hit, please login using Hik-Connect app and then retry."
+            )
             # GET v3/captcha?account=tomasbedrich&featureCode=deadbeef => receives PNG with CATPCHA, the code must be send with next request inside `imageCode` field
 
         try:
@@ -85,7 +91,9 @@ class HikConnect:
             "featureCode": _HikConnectClient.FEATURE_CODE,
         }
         with self.client.without_session_id() as client:
-            async with client.put(f"{self.BASE_URL}/v3/apigateway/login", data=data) as res:
+            async with client.put(
+                f"{self.BASE_URL}/v3/apigateway/login", data=data
+            ) as res:
                 res_json = await res.json()
         log.debug("Got refresh login response '%s'", res_json)
 
@@ -105,46 +113,56 @@ class HikConnect:
     def _handle_login_response(self, session_id, refresh_session_id):
         self.client.set_session_id(session_id)
         self.login_valid_until = self._decode_jwt_expiration(session_id)
-        log.debug("Parsed session_id '%s', valid until %s", session_id, self.login_valid_until)
+        log.debug(
+            "Parsed session_id '%s', valid until %s", session_id, self.login_valid_until
+        )
         self._refresh_session_id = refresh_session_id
         log.debug("Parsed refresh_session_id '%s'", self._refresh_session_id)
 
     def is_refresh_login_needed(self):
-        return (self.login_valid_until - datetime.datetime.now()) < datetime.timedelta(hours=1)
+        return (self.login_valid_until - datetime.datetime.now()) < datetime.timedelta(
+            hours=1
+        )
 
     async def get_devices(self):
         """Get info about devices associated with currently logged user."""
-        async with self.client.get(
-            f"{self.BASE_URL}/v3/userdevices/v1/devices/pagelist?groupId=-1&limit=100&offset=0&filter=TIME_PLAN,CONNECTION,SWITCH,STATUS,STATUS_EXT,WIFI,NODISTURB,P2P,KMS,HIDDNS"
-        ) as res:
-            res_json = await res.json()
-        log.debug("Got device list response '%s'", res_json)
-        log.info("Received device list")
-        for device in res_json["deviceInfos"]:
-            serial = device["deviceSerial"]
-            try:
-                locks_json = json.loads(res_json["statusInfos"][serial]["optionals"]["lockNum"])
-                # "lockNum" format: {"1":1,"2":1,"3":1,"4":1,"5":1,"6":1,"7":1,"8":1}
-                # which means (guessing): <channel number>: <number of locks connected>
-                locks = {int(k): v for k, v in locks_json.items()}
-            except KeyError:
-                # some devices doesn't have "lockNum"
-                # (for example https://www.hikvision.com/cz/products/IP-Products/Network-Video-Recorders/Pro-Series/ds-7608ni-k2-8p/)
-                locks = {}
-            yield {
-                "id": device["fullSerial"],
-                "name": device["name"],
-                "serial": serial,
-                "type": device["deviceType"],
-                "version": device["version"],
-                "locks": locks,
-            }
-        if res_json["page"]["hasNext"]:
-            raise ValueError("More than 100 devices is not supported yet. Please file an issue on GitHub.")
+        limit, offset, has_next_page = 50, 0, True
+        while has_next_page:
+            async with self.client.get(
+                f"{self.BASE_URL}/v3/userdevices/v1/devices/pagelist?groupId=-1&limit={limit}&offset={offset}&filter=TIME_PLAN,CONNECTION,SWITCH,STATUS,STATUS_EXT,WIFI,NODISTURB,P2P,KMS,HIDDNS"
+            ) as res:
+                res_json = await res.json()
+            log.debug("Got device list response '%s'", res_json)
+            log.info("Received device list")
+            for device in res_json["deviceInfos"]:
+                serial = device["deviceSerial"]
+                try:
+                    locks_json = json.loads(
+                        res_json["statusInfos"][serial]["optionals"]["lockNum"]
+                    )
+                    # "lockNum" format: {"1":1,"2":1,"3":1,"4":1,"5":1,"6":1,"7":1,"8":1}
+                    # which means (guessing): <channel number>: <number of locks connected>
+                    locks = {int(k): v for k, v in locks_json.items()}
+                except KeyError:
+                    # some devices doesn't have "lockNum"
+                    # (for example https://www.hikvision.com/cz/products/IP-Products/Network-Video-Recorders/Pro-Series/ds-7608ni-k2-8p/)
+                    locks = {}
+                yield {
+                    "id": device["fullSerial"],
+                    "name": device["name"],
+                    "serial": serial,
+                    "type": device["deviceType"],
+                    "version": device["version"],
+                    "locks": locks,
+                }
+            offset += limit
+            has_next_page = res_json["page"]["hasNext"]
 
     async def get_cameras(self, device_serial: str):
         """Get info about cameras connected to a device."""
-        async with self.client.get(f"{self.BASE_URL}/v3/userdevices/v1/cameras/info?deviceSerial={device_serial}") as res:
+        async with self.client.get(
+            f"{self.BASE_URL}/v3/userdevices/v1/cameras/info?deviceSerial={device_serial}"
+        ) as res:
             res_json = await res.json()
         log.debug("Got camera list response '%s'", res_json)
         log.info("Received camera info for device '%s'", device_serial)
@@ -157,7 +175,9 @@ class HikConnect:
                 "is_shown": camera["isShow"],
             }
 
-    async def unlock(self, device_serial: str, channel_number: int, lock_index: int = 0):
+    async def unlock(
+        self, device_serial: str, channel_number: int, lock_index: int = 0
+    ):
         """
         Send unlock request.
 
@@ -171,10 +191,17 @@ class HikConnect:
         ) as res:
             res_json = await res.json()
         log.debug("Got unlock response '%s'", res_json)
-        log.info("Unlocked device '%s' channel '%d' lock_index '%d'", device_serial, channel_number, lock_index)
+        log.info(
+            "Unlocked device '%s' channel '%d' lock_index '%d'",
+            device_serial,
+            channel_number,
+            lock_index,
+        )
 
     async def get_call_status(self, device_serial: str):
-        async with self.client.get(f"{self.BASE_URL}/v3/devconfig/v1/call/{device_serial}/status") as res:
+        async with self.client.get(
+            f"{self.BASE_URL}/v3/devconfig/v1/call/{device_serial}/status"
+        ) as res:
             res_json = await res.json()
         log.debug("Got call status response '%s'", res_json)
         log.info("Got call status for device '%s'", device_serial)
